@@ -3,6 +3,8 @@
 #![allow(non_camel_case_types)]
 #![allow(non_snake_case)]
 #![allow(improper_ctypes)]
+#![allow(clippy::redundant_static_lifetimes)]
+#![allow(clippy::upper_case_acronyms)]
 include!("../../generated/hts.rs");
 
 #[cfg(no_bam_hdr_destroy)]
